@@ -47,14 +47,14 @@ ExportMenu::ExportMenu(QWidget *parent)
 
 #ifdef PURPOSE_FOUND
     loadPurposeMenu();
-    connect(ExportManager::instance(), &ExportManager::pixmapChanged, this, &ExportMenu::onPixmapChanged);
+    connect(ExportManager::instance(), &ExportManager::imageChanged, this, &ExportMenu::onImageChanged);
 #endif
 
     addSeparator();
     getKServiceItems();
 }
 
-void ExportMenu::onPixmapChanged()
+void ExportMenu::onImageChanged()
 {
 #ifdef PURPOSE_FOUND
     // mark cached image as stale
@@ -84,7 +84,7 @@ void ExportMenu::getKServiceItems()
                 filename = Settings::self()->lastSaveLocation();
             } else {
                 filename = ExportManager::instance()->getAutosaveFilename();
-                ExportManager::instance()->doSave(filename);
+                ExportManager::instance()->exportImage(ExportManager::Save, filename);
             }
 
             auto *job = new KIO::ApplicationLauncherJob(service);
@@ -116,7 +116,7 @@ void ExportMenu::getKServiceItems()
             filename = Settings::self()->lastSaveLocation();
         } else {
             filename = ExportManager::instance()->getAutosaveFilename();
-            ExportManager::instance()->doSave(filename);
+            ExportManager::instance()->exportImage(ExportManager::Save, filename);
         }
 
         auto job = new KIO::ApplicationLauncherJob;
